const util = require('../src/merge.js')
const sinon = require('sinon')

describe('merge suites', () => {
  it('should merge empty lists', () => {
    expect(util.merge([], [])).to.deep.equal([])
  })
  const l1 = [
    { title: 'test 1', state: 'passed' },
    { title: 'test 2' }
  ]
  const l2 = [
    { title: 'test 2' },
    { title: 'test 3', state: 'passed' }
  ]
  const duplicates = [
    { title: 'test 1', state: 'passed' },
    { title: 'test 3' }
  ]

  it('should return first list if second is empty', () => {
    expect(util.merge(l1, [])).to.deep.equal(l1)
  })
  it('should return second list if first is empty', () => {
    expect(util.merge([], l2)).to.deep.equal(l2)
  })
  it('should merge but print a warning if two entries with a state are detected', () => {
    const spy = sinon.stub(console, 'warn')
    expect(util.merge(l1, duplicates)).to.deep.equal([
      { title: 'test 1', state: 'passed' },
      { title: 'test 2' },
      { title: 'test 3' }
    ])
    expect(spy.calledOnce, 'console.warn called').to.equal(true)
    spy.restore()
  })
  it('should always be sorted by title', () => {
    const spy = sinon.stub(console, 'warn')
    let list1, list2
    list1 = util.merge(l1, l2)
    list1 = util.merge(list1, duplicates)
    list2 = util.merge(duplicates, l2)
    list2 = util.merge(l2, l1)
    expect(list1).to.deep.equal(list2)
    expect(spy.calledOnce, 'console.warn called').to.equal(true)
    spy.restore()
  })
})
