import { createServer as netCreateServer } from 'node:net'

export function getFilesFromBundle (name, bundle) {
  return bundle?.output?.filter(({ fileName }) => fileName.indexOf(name) >= 0)
}

export function getFileFromBundle (name, bundle) {
  const files = getFilesFromBundle(name, bundle)
  if (!files) return
  if (files.length <= 1) return files[0]
  return bundle.output.find(({ fileName }) => fileName === name)
}

const usedPorts = []

export async function getPort () {
  return await new Promise((resolve, reject) => {
    const server = netCreateServer()
    let port = 0

    server.once('listening', () => {
      const address = server.address()

      if (address == null) {
        return reject(new Error('Server was not listening'))
      }

      if (typeof address === 'string') {
        return reject(new Error('Server was Unix Socket'))
      }

      port = address.port
      server.close()
    })
    server.once('close', () => {
      if (usedPorts.includes(port)) {
        return getPort().then(resolve, reject)
      }
      usedPorts.push(port)
      resolve(port)
    })
    server.once('error', reject)
    server.listen(0, '127.0.0.1')
  })
}
